extensions [csv nw]

globals [
  ;inputs

  work_potatowheat
  cost_potatowheat

  workAF0
  workAFweeding
  workAFpruning
  workAF20

  outputgrevillea outputalnus outputmakamia
  outputpotato outputwheat
  potato-price wheat-price
  potatooutputAF wheatoutputAF

  woodprice
  wage

  caloric-threshold

  ;Behavioral theory inputs
  ;tpb
  w_att w_pbc w_know w_SN
  w_ctpb1   w_ctpb2   w_ctpb6   w_ctpb9   w_ctpb10   w_ctpb11   w_ctpb12   w_ctpb13   w_ctpb19   w_ctpb21

  ;Probabilistic
  beta_zero  beta_landsize  beta_HHsize beta_landquality beta_valuebiodi beta_nonworkers


  ;validation
  vali1 vali2 vali3
  under1 under2 under3 over1 over2 over3

  ;model outputs
  adopters adoptersshare
  meanincome
  AFarea AFareashare
  meanincomea
  meanincomena

]

turtles-own [
  ;from survey
  HHID  landsize nonworkers adopter income valuebiodi friends my-plots  hhsize ilaborforce actuallaborforce landquality extensionaccess
  ;simulated
  nurseryaccess
  ;TPB
  Attitude  PBC SN   Intention ctpb1 ctpb2 ctpb6 ctpb9 ctpb10 ctpb11 ctpb12 ctpb13 ctpb19 ctpb21 ctpb23b ctpb24b
  ;validation
  vali-1 vali-2 vali-3

]

patches-own [
  owner sizeha agroforestry  AFage potatowheat
]


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                                                                SETUP                                                                           ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  clear-all
  reset-ticks
  setup-farmers
  setup-background
  setup-globals
  setup-vali
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-farmers
  file-close-all
  file-open "data/NetLogo.csv"
  let headings csv:from-row file-read-line
  while [ not file-at-end? ] [
    let data csv:from-row file-read-line
    create-turtles 1 [
      set HHID  item 0 data
      set landsize item 3 data
      set valuebiodi item 9 data
      set friends item 43 data
      set hhsize item 6 data
      set nonworkers item 19 data
      set ilaborforce (hhsize - nonworkers) * 365
      set landquality item 7 data
      set extensionaccess item 37 data

      set ctpb1 item 166 data
      set ctpb2 item 167 data
      set ctpb6 item 171 data
      set ctpb9 item 174 data
      set ctpb10 item 175 data
      set ctpb11 item 176 data
      set ctpb12 item 177 data
      set ctpb13 item 178 data
      set ctpb19 item 184 data
      set ctpb21 item 186 data
      set ctpb23b item 144 data
      set ctpb24b item 146 data


      set adopter 0
      set shape "turtle"
      set size 1.5
      set income 0

      ifelse random 100 < 10
      [set nurseryaccess 1]
      [set nurseryaccess 0]

    ]
  ]
  file-close-all

  ask turtles [

    move-to one-of patches with [not any? turtles-here]
    ;make visualization match an approximate of the actual distribution
    ;patches represent 0.5ha
    let num-patches 0
    if landsize <  0.75 [set num-patches 1]
    if landsize >= 0.75 AND landsize < 1.25 [set num-patches 2 ]
    if landsize >= 1.25 AND landsize < 1.75 [set num-patches 3]
    if landsize >= 1.75 AND landsize < 2.25 [set num-patches 4]
    if landsize >= 2.25 AND landsize < 2.75 [set num-patches 5]
    if landsize >= 2.75 AND landsize < 3.25 [set num-patches 6]
    if landsize >= 3.25 AND landsize < 3.75 [set num-patches 7]
    if landsize >= 3.75 AND landsize < 4.25 [set num-patches 8]
    if landsize >= 4.25 AND landsize < 4.75 [set num-patches 9]
    if landsize >= 4.75 AND landsize < 5.25 [set num-patches 10]
    if landsize >= 5.25 AND landsize < 5.75 [set num-patches 11]
    if landsize >= 5.75 [set num-patches 12]
    let sizeeach landsize / num-patches
    ask min-n-of num-patches patches with [owner = 0][distance myself] [
      set pcolor [color] of myself
      set owner [HHID] of myself
      set sizeha sizeeach
    ]

    set my-plots patches with [owner = [HHID] of myself]

    ; change number of friends if it is larger than 99 to 6 in line with descriptive statistics (remove outliers)
    if friends > 99 [set friends 6]
    let candidates n-of friends other turtles
    create-links-to candidates [set hidden? true]
  ]
end


to setup-background
  ask patches [
    set pcolor green + 2
    set agroforestry -99
    set AFage -99
    set potatowheat 0
  ]
  ask patches with [owner != 0] [set pcolor green - 2]
end



to setup-globals
  ;inputs

  set wage 800

  ;work in work- days
  ;potatoes and wheat
  set work_potatowheat (11 + 99.5)

  ;inputs: costs without labor (Fertilizer (DAP and NPK), Pesticides, and seeds for wheat and potatoes
  set cost_potatowheat (180900 + 48000 + 17059 + 17500 + 217528)

  ; work days
  set workAF0 (14.6 + 7.1)
  set workAFweeding 16
  set workAFpruning 8.8
  set workAF20 36.5 + 121.9

  ;kg/ha
  set outputgrevillea 94.392
  set outputalnus 200
  set outputmakamia 434

  set outputpotato 10986.5
  set outputwheat 1221

  set potato-price 300
  set wheat-price 700

  set potatooutputAF 34167
  set wheatoutputAF 1759

  set woodprice 115000

  set caloric-threshold 2188

  ;globals for decision-making

  ;TPB
  set w_att 0.425177630468861
  set w_pbc 0.131460819256337
  set w_sn 0.182419064459261
  set w_ctpb1 0.263214913469406
  set w_ctpb2 0.194215821339091
  set w_ctpb6 0.157252278726265
  set w_ctpb9 0.273018446592795
  set w_ctpb10 0.223796011998569
  set w_ctpb11 0.273895861103939
  set w_ctpb12 0.843489187331585
  set w_ctpb13 0.311983546753898
  set w_ctpb19 0.798255490734562
  set w_ctpb21 0.494505190263593

  ;Econometric (logistic) regression
  set beta_zero  -0.4138946
  set beta_landsize  2.900942
  set beta_HHsize 0.6224932
  set beta_landquality  -1.554297
  set beta_valuebiodi 0.9342724
  set beta_nonworkers  -0.0376105
end

to setup-vali
  ask turtles [set vali-1 -99 set vali-2 -99 set vali-3 -99]
  file-close-all
  file-open "data/vali.csv"
  let headings csv:from-row file-read-line
  while [ not file-at-end? ] [
    let data2 csv:from-row file-read-line
    let current-turtle item 0 data2
    ask turtles with [HHID = current-turtle]
    [
      if (item 1 data2) = 1 [ set vali-1 item 6 data2]
      if (item 1 data2) = 2 [ set vali-2 item 6 data2]
      if (item 1 data2) = 3 [ set vali-3 item 6 data2]
    ]
  ]
  file-close-all
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;                                                                  GO                                                                            ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  if ticks = 30 [stop]

  vegetation

  ask turtles
  [
    ;Prepare
    set actuallaborforce ilaborforce

    if adopter = 0 [
      if behavior = "random" [decide-randomly]
      if behavior = "utility" [decide-utility]
      if behavior = "discounted utility" [decide-discounted-utility]
      if behavior = "TPB" [decide-TPB]
      if behavior = "econometric" [decide-logit]
      if behavior = "satisficing" [decide-satisficing]
      if behavior = "decision tree" [ decide-decision-tree]
    ]

    harvest

    consume

    maintainAF

    if employment? = true [employment-income]

  ]
  tick
  update-outputs

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to vegetation
  ask patches with [AFage > (-1)] [
    set AFage AFage + 1
  ]
end


to decide-randomly
  ifelse random-float 100 > 50
  [
    adopt
  ][
    plantpotatowheat
  ]
end


to decide-utility

  let plannedlaborforce ilaborforce
  let futurelaborforce ilaborforce

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;        potatoes         ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;labor costs
  let cost_work_potatowheat 0
  let future_cost_work_potatowheat 0
  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)

  ifelse plannedlaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed
    set cost_work_potatowheat (workers_potatowheat_needed - plannedlaborforce) * wage
    set plannedlaborforce 0
    set futurelaborforce 0
  ]
  [
    ;use hh labor
    set cost_work_potatowheat 0
    set plannedlaborforce plannedlaborforce - workers_potatowheat_needed
    set futurelaborforce plannedlaborforce
  ]

  ;utility potatoes, for 20 years as well
  let utility_potatowheat (( potato-price * outputpotato  + wheat-price * outputwheat - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat  ) * 20


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;           AF            ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ;work in year 0
  let workers_AF_needed (round (workAF0 * (sum [sizeha] of my-plots)))
  ; from the plannedlaborforce it is alsready subtracted how much households need for potatoes
  ifelse plannedlaborforce < workers_AF_needed
  [
    ;hire
    set workers_AF_needed workers_AF_needed - plannedlaborforce
    set plannedlaborforce 0
  ]
  [
    ;use hh labor
    set plannedlaborforce plannedlaborforce - workers_AF_needed
    set workers_AF_needed 0
  ]
  let cost_work_AF0 workers_AF_needed * wage


  ;add work costs
  let furtherworkcostsAF 0

  ;maintenance
  ;weeding
  let work_AFweeding_needed (round workAFweeding * (sum [sizeha] of my-plots))
  ifelse futurelaborforce < work_AFweeding_needed
  [
    ;hire
    set work_AFweeding_needed work_AFweeding_needed - futurelaborforce
  ]
  [
    ;use hh labor
    set work_AFweeding_needed 0
  ]
  let cost_work_AFweeding work_AFweeding_needed * wage

  ;pruning
  let work_AFpruning_needed (round workAFpruning * (sum [sizeha] of my-plots))
  ifelse futurelaborforce < work_AFpruning_needed
  [
    ;hire
    set work_AFpruning_needed work_AFpruning_needed - futurelaborforce
  ]
  [
    ;use hh labor
    set work_AFpruning_needed 0
  ]
  let cost_work_AFpruning work_AFpruning_needed * wage


  ;weeding in two years, pruning in 3

  set furtherworkcostsAF cost_work_AFweeding * 2 + cost_work_AFpruning * 3

  ;after 20 years trees are  completely cut

  ;work in year 20
  let workers_AF20_needed (round (workAF20 * (sum [sizeha] of my-plots)))
  ; from the futurelaborforce it is alsready subtracted how much households need for potatoes
  ifelse futurelaborforce < workers_AF20_needed
  [
    ;hire
    set workers_AF20_needed workers_AF20_needed - futurelaborforce
  ]
  [
    ;use hh labor
    set workers_AF20_needed 0
  ]
  let cost_work_AF20 workers_AF20_needed * wage



  let AFoutput ((  outputgrevillea + outputalnus + outputmakamia ) * woodprice) * (sum [sizeha] of my-plots )

  let utility_potatowheatAF (( potato-price * potatooutputAF  + wheat-price * wheatoutputAF - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat  ) * 20

  let normal_utility_AF AFoutput - cost_work_AF0   - furtherworkcostsAF + utility_potatowheatAF


  ifelse normal_utility_AF >= utility_potatowheat
  [
    adopt
  ]
  [plantpotatowheat
  ]
end





to decide-discounted-utility

  let plannedlaborforce ilaborforce
  let futurelaborforce ilaborforce

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;        potatoes         ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;labor costs
  let cost_work_potatowheat 0
  let future_cost_work_potatowheat 0
  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)
  ifelse plannedlaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed

    set cost_work_potatowheat (workers_potatowheat_needed - plannedlaborforce) * wage
    set plannedlaborforce 0
    set futurelaborforce 0
  ]
  [
    ;use hh labor
    set cost_work_potatowheat 0
    set plannedlaborforce plannedlaborforce - workers_potatowheat_needed
    set futurelaborforce plannedlaborforce
  ]

  ;utility potatoes
  let utility_potatowheat ( potato-price * outputpotato  + wheat-price * outputwheat - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat

  let disc_utility_potatowheat 0
  let yearpotatowheat 0
  repeat 21
  [
    set disc_utility_potatowheat disc_utility_potatowheat + (utility_potatowheat / ( (1 + 0.01 * discounting-factor) ^ yearpotatowheat))
    set yearpotatowheat yearpotatowheat + 1
  ]


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;           AF            ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;investment costs in year 0, which are subtracted later
  ;work in year 0
  let workers_AF_needed (round (workAF0 * (sum [sizeha] of my-plots)))
  ; from the plannedlaborforce it is alsready subtracted how much households need for potatoes
  ifelse plannedlaborforce < workers_AF_needed
  [
    ;hire
    set workers_AF_needed workers_AF_needed - plannedlaborforce
    set plannedlaborforce 0
  ]
  [
    ;use hh labor
    set plannedlaborforce plannedlaborforce - workers_AF_needed
    set workers_AF_needed 0
  ]

  let cost_work_AF0 workers_AF_needed * wage

  let utility_potatowheatAF ( potato-price * potatooutputAF  + wheat-price * wheatoutputAF - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat


  ;  discount the net benefit each year

  let disc_utility_AF 0
  let year 1
  repeat 20
  [
    ;every year: potatowheat
    set disc_utility_AF disc_utility_AF + (( utility_potatowheatAF) / ( (1 + 0.01 * discounting-factor) ^ year))


    if year = 1 or year = 2
    ;maintenance: weeding
    [
      let costmaintenanceworkw 0
      if futurelaborforce  < round (workAFweeding * (sum [sizeha] of my-plots ))
      [
        ;hire
        let diff round (workAFweeding * (sum [sizeha] of my-plots )) - futurelaborforce
        set costmaintenanceworkw diff * wage
      ]
      set disc_utility_AF disc_utility_AF - (costmaintenanceworkw / ( (1 + 0.01 * discounting-factor) ^ year))
    ]

    ; maintenance (pruning)
    if year = 3 or year = 7 or year = 10
    [
      let costmaintenanceworkp 0
      if futurelaborforce  < round (workAFpruning * (sum [sizeha] of my-plots ))
      [
        ;hire
        let diff round (workAFpruning * (sum [sizeha] of my-plots )) - futurelaborforce
        set costmaintenanceworkp diff * wage
      ]
      set disc_utility_AF disc_utility_AF - (costmaintenanceworkp / ( (1 + 0.01 * discounting-factor) ^ year))
    ]


    ;harvest
    if year = 20
    [
      let costharvestAFwork 0
      if futurelaborforce  < round (workAF20 * (sum [sizeha] of my-plots ))
      [
        ;hire
        let diff2 round (workAF20 * (sum [sizeha] of my-plots )) - futurelaborforce
        set costharvestAFwork diff2 * wage
      ]
      ;harvest
      let AFharvest ((  outputgrevillea + outputalnus + outputmakamia ) * woodprice) * (sum [sizeha] of my-plots )
      let utility_AF AFharvest - costharvestAFwork
      set disc_utility_AF disc_utility_AF + (utility_AF / ( (1 + 0.01 * discounting-factor) ^ year))
    ]

    set year year + 1
  ]


  ; subtract the labor costs that take place in year 0
  set disc_utility_AF disc_utility_AF - cost_work_AF0

  ifelse disc_utility_AF >= disc_utility_potatowheat
  [
    adopt
  ]
  [plantpotatowheat
  ]
end




to decide-TPB

  ;attitude
  set Attitude (w_ctpb1 * ctpb1 + w_ctpb2 * ctpb2 + w_ctpb6 * ctpb6 + w_ctpb9 * ctpb9 + w_ctpb10 * ctpb10 + w_ctpb11 * ctpb11)
  ;PBC
  set PBC (w_ctpb19 * ctpb19 + w_ctpb21 * ctpb21)
  ;SN
  set SN (w_ctpb12 * ctpb12 + w_ctpb13 * ctpb13)
  ; if many friends are adopters, SN can change
  if SNchange? = TRUE [
    let adopterfriends count out-link-neighbors with [adopter = 1]
    let shareadopterfriends 0
    if count out-link-neighbors > 0
    [
      set shareadopterfriends (adopterfriends / (count out-link-neighbors)) * 100]
    let relSN ( ( SN / 28.8868 ) * 100 )
    if shareadopterfriends > relSN
    [ set SN  shareadopterfriends * 28.8868 / 100
    ]
  ]
  if SN > 28.8868 [set SN 28.8868]

  set intention (  w_att * Attitude +  w_pbc * PBC + w_sn * SN )
  ;intention between 0.96 und 24.21
  ;scale it to 100
  set intention (intention - 0.96)
  set intention (intention * 100 / 23.25)

  ifelse  random 100 < intention
  [
    adopt
  ][
    plantpotatowheat
  ]
end


to decide-logit
  ;log-odds
  let logodds (beta_zero + beta_landsize * landsize + beta_HHsize * HHsize + beta_landquality * landquality + beta_valuebiodi * valuebiodi + beta_nonworkers * nonworkers)

  ;odds:
  let odds ( exp logodds)

  ;probability
  let prob (odds / (1 + odds ) )

  set prob prob * 100

  ifelse  random 100 < prob [
    adopt
  ][
    plantpotatowheat
  ]
end

to decide-satisficing

  let plannedlaborforce ilaborforce
  let futurelaborforce ilaborforce

  ; one calorie of potatoes costs 0.44776119 RWF, thus multiply with needed kcal
  let potato-needed-in-RWF caloric-threshold * hhsize * 365 * 0.44776119
  ;adjust the potato consumption required for FS in RWF, for 20 years
  let threshold (potato-needed-in-RWF) * 20

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;        potatoes         ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ;Potato monoculture

  ;labor costs
  let cost_work_potatowheat 0
  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)
  ifelse plannedlaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed
    set cost_work_potatowheat (workers_potatowheat_needed - plannedlaborforce) * wage
    set plannedlaborforce 0
    set futurelaborforce 0
  ]
  [
    ;use hh labor
    set cost_work_potatowheat 0
    set plannedlaborforce plannedlaborforce - workers_potatowheat_needed
    set futurelaborforce plannedlaborforce
  ]

  ;utility potatoes, for 20 years as well
  let utility_potatowheat (( potato-price * outputpotato  + wheat-price * outputwheat - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat  ) * 20


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;           AF            ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ;work in year 0
  let workers_AF_needed (round (workAF0 * (sum [sizeha] of my-plots)))
  ; from the plannedlaborforce it is alsready subtracted how much households need for potatoes
  ifelse plannedlaborforce < workers_AF_needed
  [
    ;hire
    set workers_AF_needed workers_AF_needed - plannedlaborforce
    set plannedlaborforce 0
  ]
  [
    ;use hh labor
    set plannedlaborforce plannedlaborforce - workers_AF_needed
    set workers_AF_needed 0
  ]
  let cost_work_AF0 workers_AF_needed * wage


  ;add work costs
  let furtherworkcostsAF 0

  ;maintenance
  ;weeding
  let work_AFweeding_needed (round workAFweeding * (sum [sizeha] of my-plots))
  ifelse futurelaborforce < work_AFweeding_needed
  [
    ;hire
    set work_AFweeding_needed work_AFweeding_needed - futurelaborforce
    ; set plannedlaborforce 0
  ]
  [
    ;use hh labor
    ;set plannedlaborforce plannedlaborforce - work_AFweeding_needed
    set work_AFweeding_needed 0
  ]
  let cost_work_AFweeding work_AFweeding_needed * wage

  ;maintenance
  ;pruning
  let work_AFpruning_needed (round workAFpruning * (sum [sizeha] of my-plots))
  ifelse futurelaborforce < work_AFpruning_needed
  [
    ;hire
    set work_AFpruning_needed work_AFpruning_needed - futurelaborforce
  ]
  [
    ;use hh labor
    set work_AFpruning_needed 0
  ]
  let cost_work_AFpruning work_AFpruning_needed * wage



  ;weeding in two years, pruning in 3

  set furtherworkcostsAF cost_work_AFweeding * 2 + cost_work_AFpruning * 3

  ;after 20 years trees are  completely cut

  ;work in year 20
  let workers_AF20_needed (round (workAF20 * (sum [sizeha] of my-plots)))
  ; from the plannedlaborforce it is alsready subtracted how much households need for potatoes
  ifelse futurelaborforce < workers_AF20_needed
  [
    ;hire
    set workers_AF20_needed workers_AF20_needed - plannedlaborforce
  ]
  [
    ;use hh labor
    set workers_AF20_needed 0
  ]
  let cost_work_AF20 workers_AF20_needed * wage


  let AFoutput ((  outputgrevillea + outputalnus + outputmakamia ) * woodprice) * (sum [sizeha] of my-plots )

  let utility_potatowheatAF (( potato-price * potatooutputAF  + wheat-price * wheatoutputAF - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat  ) * 20

  let normal_utility_AF AFoutput - cost_work_AF0   - furtherworkcostsAF + utility_potatowheatAF



  ifelse random-float 100 < 50
  [ifelse utility_potatowheat > threshold
    [
      plantpotatowheat
    ]
    [ ifelse normal_utility_AF > threshold [adopt ] [  ]
    ]
  ]
  [ifelse normal_utility_AF > threshold
    [adopt  ]
    [ifelse utility_potatowheat > threshold [plantpotatowheat ] [ ]
    ]
  ]

end



to decide-decision-tree

  let plannedlaborforce ilaborforce
  let futurelaborforce ilaborforce

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;        potatoes         ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;labor costs

  let cost_work_potatowheat 0
  let future_cost_work_potatowheat 0
  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)


  ifelse plannedlaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed
    set cost_work_potatowheat (workers_potatowheat_needed - plannedlaborforce) * wage
    set plannedlaborforce 0
    set futurelaborforce 0
  ]
  [
    ;use hh labor
    set cost_work_potatowheat 0
    set plannedlaborforce plannedlaborforce - workers_potatowheat_needed
    set futurelaborforce plannedlaborforce
  ]

  ;utility potatoes, for 20 years as well
  let utility_potatowheat ( potato-price * outputpotato  + wheat-price * outputwheat - cost_potatowheat  ) * (sum [sizeha] of my-plots ) - cost_work_potatowheat


  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;     decision tree       ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ifelse landquality < 4 OR  ((outputpotato * (sum [sizeha] of my-plots ) * 670) + ((outputwheat * (sum [sizeha] of my-plots )) * 3340)) < caloric-threshold * hhsize * 365
  [
    ; if bad landquality or basic needs not met
    ifelse nurseryaccess = 1
    [
      ;if access to nursery
      ifelse (ctpb23b > 3 and ctpb24b > 3)
      [
        ; if knowledge on trees and AF
        ifelse plannedlaborforce > ( workAF0 * sum [sizeha] of my-plots )
          [
            ;if labor available
            adopt ]
        [
          ;f no labor availabe
          plantpotatowheat
        ]
      ]
      [
        ;else no knowledge on trees and AF
        ifelse extensionaccess = 1
        [
          ;if extension access
          ifelse plannedlaborforce > (workAF0  * sum [sizeha] of my-plots )
          [
            ;if labor available
            adopt ]
          [
            ;f no labor availabe
            plantpotatowheat
          ]

        ]
        [
          ;else no extension acces
          plantpotatowheat
        ]
      ]
    ]
    [
      ;else no access to nursery
      ifelse extensionaccess = 1
      [
        ;if extension access
        ifelse plannedlaborforce > ( workAF0 * sum [sizeha] of my-plots )
        [
          ;if labor available
          adopt ]
        [
          ;f no labor availabe
          plantpotatowheat
        ]
      ]
      [
        ;else no extension acces
        plantpotatowheat
      ]
    ]
  ]
  [
    ;else: good landquality and basic needs are met
    plantpotatowheat
  ]
end


to plantpotatowheat
  set adopter 0
  ask my-plots [
    set potatowheat 1
    set agroforestry -99
    set pcolor brown
  ]

  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)
  let cost_work_potatowheat 0
  ifelse actuallaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed
    set cost_work_potatowheat (workers_potatowheat_needed - actuallaborforce) * wage
    set actuallaborforce 0
  ]
  [
    ;use hh labor
    set actuallaborforce actuallaborforce - workers_potatowheat_needed
  ]

  ;subtract costs from income
  set income  income - cost_work_potatowheat - (cost_potatowheat * sum [sizeha] of my-plots)
end




to adopt
  set adopter 1
  ask my-plots [
    set agroforestry 0
    set AFage 0
    set pcolor 64
    set potatowheat 0
  ]

  ;fist
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;        potatoes         ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  let workers_potatowheat_needed round(work_potatowheat * sum [sizeha] of my-plots)
  let cost_work_potatowheat 0
  ifelse actuallaborforce < workers_potatowheat_needed
  [
    ;hire
    ;calculate the costs for excess labor needed
    set cost_work_potatowheat (workers_potatowheat_needed - actuallaborforce) * wage
    set actuallaborforce 0
  ]
  [
    ;use hh labor
    set actuallaborforce actuallaborforce - workers_potatowheat_needed
  ]

  ;subtract costs from income
  set income  income - cost_work_potatowheat - (cost_potatowheat * sum [sizeha] of my-plots)

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;           AF            ;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;labor costs
  let workers_AF_needed round(workAF0 *  sum [sizeha] of my-plots)


  ; from the laborforce it is alsready subtracted how much households need for potatoes

  ifelse actuallaborforce < workers_AF_needed
  [
    set workers_AF_needed workers_AF_needed - actuallaborforce
    set actuallaborforce 0
  ]
  [
    set actuallaborforce actuallaborforce - workers_AF_needed
    set workers_AF_needed 0
  ]

  ;only work for year 0 considered
  let cost_work_AF0 workers_AF_needed * wage
  set income  income - cost_work_AF0
end


to harvest

  ifelse adopter = 0 [

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;        potatoes         ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    let income-potato ( potato-price * outputpotato  ) * (sum [sizeha] of my-plots )
    let income-wheat (wheat-price * outputwheat ) * (sum [sizeha] of my-plots )
    set income income + income-potato + income-wheat
  ]

  ;else: adopter
  [
    ;first:
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;        potatoes         ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    let income_potatoAF ( potato-price *  potatooutputAF ) * (sum [sizeha] of my-plots )
    let income_wheatAF ( wheat-price *  wheatoutputAF ) * (sum [sizeha] of my-plots )
    set income income + income_potatoAF + income_wheatAF



    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;           AF            ;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;


    if AFage = 20
    [
      let workers_AFharvest_needed round (workAF20 * (sum [sizeha] of my-plots ))

      ; from the laborforce it is alsready subtracted how much households need for potatoes and vernonia harvest
      ifelse actuallaborforce <   workers_AFharvest_needed
      [
        ;hire
        set workers_AFharvest_needed  workers_AFharvest_needed  - actuallaborforce
        set actuallaborforce 0
      ]
      [
        ;use hh labor
        set actuallaborforce actuallaborforce - workers_AFharvest_needed
        set workers_AFharvest_needed  0
      ]
      let cost_workers_AFharvest_needed  workers_AFharvest_needed * wage
      set income income - cost_workers_AFharvest_needed

      let harvesttimber  (sum [sizeha] of my-plots ) *   ( outputgrevillea + outputalnus + outputmakamia) * woodprice
      set income income + harvesttimber

    ]
  ]
end


to consume
  let potato-needed-in-RWF caloric-threshold * hhsize * 365 * 0.44776119
  let consumption (potato-needed-in-RWF  )
  set income income - consumption
end


to maintainAF
  if any? my-plots with [ AFage = 1 or AFage = 2 ] [

    ifelse actuallaborforce < round ((sum [sizeha] of my-plots ) * workAFweeding)
    [
      ;hire
      let diff ( round ((sum [sizeha] of my-plots ) * workAFweeding) - actuallaborforce)
      set income income - wage * diff
      set actuallaborforce 0
    ]
    [
      ;use hh labor
      set actuallaborforce actuallaborforce - round ((sum [sizeha] of my-plots ) * workAFweeding)
    ]
  ]

  if any? my-plots with [ AFage  = 3 or  AFage = 7 or  AFage = 10] [

    ifelse actuallaborforce < round ((sum [sizeha] of my-plots ) * workAFpruning)
    [
      ;hire
      let diff ( round ((sum [sizeha] of my-plots ) * workAFpruning) - actuallaborforce)
      set income income - wage * diff
      set actuallaborforce 0
    ]
    [
      ;use hh labor
      set actuallaborforce actuallaborforce - round ((sum [sizeha] of my-plots ) * workAFpruning)
    ]
  ]
end


to employment-income
  let e-income actuallaborforce * wage
  set income income + e-income
end


to update-outputs
  if any? turtles with [vali-1 >= 0][
    if ticks = 1 [
      let correct-matches1 ((count turtles with [adopter = 0 and vali-1 = 1]) + (count turtles with [adopter = 1 and vali-1 > 1]))
      let all-vali1 count turtles with [vali-1 > 0]
      set vali1 (correct-matches1 ) * 100 / (all-vali1)
      set under1 (count turtles with [adopter = 0 and vali-1 > 1] * 100 / all-vali1 )
      set over1 (count turtles with [adopter = 1 and vali-1 = 1] * 100 / all-vali1 )

    ]
  ]
  if any? turtles with [vali-2 >= 1]
  [
    if ticks = 2 [
      let correct-matches2 ((count turtles with [adopter = 0 and vali-2 = 1]) + (count turtles with [adopter = 1 and vali-2 > 1]))
      let all-vali2 count turtles with [vali-2 > 0]
      set vali2 (correct-matches2) * 100 / (all-vali2)
      set under2 (count turtles with [adopter = 0 and vali-2 > 1] * 100 / all-vali2 )
      set over2  (count turtles with [adopter = 1 and vali-2 = 1] * 100 / all-vali2 )

    ]
    if ticks = 3 [
      let correct-matches3 ((count turtles with [adopter = 0 and vali-3 = 1]) + (count turtles with [adopter = 1 and vali-3 > 1]))
      let all-vali3 count turtles with [vali-3 > 0]
      set vali3 (correct-matches3 ) * 100 / (all-vali3)
      set under3 (count turtles with [adopter = 0 and vali-3 > 1] * 100 / all-vali3 )
      set over3  (count turtles with [adopter = 1 and vali-3 = 1] * 100 / all-vali3 )

    ]
  ]


  set adopters (count turtles with [adopter = 1])
  set adoptersshare (adopters * 100 / (count turtles) )
  set meanincome mean [income] of turtles
  set AFarea sum [landsize] of turtles with [adopter = 1]
  set AFareashare (AFarea * 100 / (sum [landsize] of turtles )  )


  ifelse any? turtles with [adopter = 1]
  [
    set meanincomea mean [income] of turtles with [adopter = 1]
  ]
  [

    set meanincomea 0

  ]

  ifelse any? turtles with [adopter = 0]
  [
    set meanincomena mean [income] of turtles with [adopter = 0]
  ]
  [
    set meanincomena 0
  ]



  set-current-plot "Validation"
  set-current-plot-pen "Vali year 1"
  plot vali1
  set-current-plot-pen "Vali year 2"
  plot vali2
  set-current-plot-pen "Vali year 3"
  plot vali3
  set-current-plot-pen "100%"
  plot 100

  set-current-plot "Land cover"
  set-current-plot-pen "agroforestry"
  let af count patches with [Agroforestry > (- 1)]
  plot (( af * 100 ) / count patches with [owner != 0 ] )
  set-current-plot-pen "potatoes and wheat"
  plot ((count patches with [potatowheat = 1 and owner != 0 ]) * 100 / count patches with [owner != 0 ])

  set-current-plot "adoption rate"
  set-current-plot-pen "adopters"
  plot (count turtles with [adopter = 1] * 100 ) / count turtles

  set-current-plot "average income"
  set-current-plot-pen "adopters"
  plot meanincomea / 1000
  set-current-plot-pen "non-adopters"
  plot meanincomena / 1000
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
683
484
-1
-1
15.0
1
10
1
1
1
0
0
0
1
-15
15
-15
15
0
0
1
ticks
30.0

BUTTON
12
44
78
77
NIL
setup
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

PLOT
695
32
1281
182
Land cover
time
%
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"agroforestry" 1.0 0 -14439633 true "" ""
"potatoes and wheat" 1.0 0 -4079321 true "" ""

BUTTON
12
90
75
123
NIL
go
NIL
1
T
OBSERVER
NIL
G
NIL
NIL
1

BUTTON
88
92
151
125
NIL
go
T
1
T
OBSERVER
NIL
F
NIL
NIL
1

PLOT
695
185
1282
335
adoption rate
time
%
0.0
10.0
0.0
100.0
true
true
"" ""
PENS
"adopters" 1.0 0 -16777216 true "" ""

PLOT
695
498
895
648
average income
time
income
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"adopters" 1.0 0 -14439633 true "" ""
"non-adopters" 1.0 0 -8431303 true "" ""

CHOOSER
9
194
182
239
behavior
behavior
"random" "utility" "discounted utility" "TPB" "econometric" "satisficing" "decision tree"
6

SLIDER
8
276
182
309
discounting-factor
discounting-factor
0
20
7.0
1
1
%
HORIZONTAL

TEXTBOX
9
171
159
189
Decisions: 
11
125.0
1

SWITCH
111
521
286
554
SNchange?
SNchange?
0
1
-1000

PLOT
695
340
1284
490
Validation
NIL
%
0.0
10.0
0.0
100.0
true
true
"" ""
PENS
"Vali year 1" 1.0 0 -14070903 true "" ""
"Vali year 2" 1.0 0 -15302303 true "" ""
"Vali year 3" 1.0 0 -14439633 true "" ""
"100%" 1.0 0 -955883 true "" ""

SWITCH
302
521
441
554
employment?
employment?
0
1
-1000

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

mouse side
false
0
Polygon -7500403 true true 38 162 24 165 19 174 22 192 47 213 90 225 135 230 161 240 178 262 150 246 117 238 73 232 36 220 11 196 7 171 15 153 37 146 46 145
Polygon -7500403 true true 289 142 271 165 237 164 217 185 235 192 254 192 259 199 245 200 248 203 226 199 200 194 155 195 122 185 84 187 91 195 82 192 83 201 72 190 67 199 62 185 46 183 36 165 40 134 57 115 74 106 60 109 90 97 112 94 92 93 130 86 154 88 134 81 183 90 197 94 183 86 212 95 211 88 224 83 235 88 248 97 246 90 257 107 255 97 270 120
Polygon -16777216 true false 234 100 220 96 210 100 214 111 228 116 239 115
Circle -16777216 true false 246 117 20
Line -7500403 true 270 153 282 174
Line -7500403 true 272 153 255 173
Line -7500403 true 269 156 268 177

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
